# coding: utf-8

"""
ME TT DataPortal Data Portal API

ME TT DataPortal Data Portal APIs to fetch Gut Microbes Genomes / Genes information.

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import StrictBool
from uuid import UUID
from mett_dataportal_sdk.models.success_response_schema import SuccessResponseSchema

from mett_dataportal_sdk.api_client import ApiClient, RequestSerialized
from mett_dataportal_sdk.api_response import ApiResponse
from mett_dataportal_sdk.rest import RESTResponseType


class PyHMMERResultsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_call
    def pyhmmer_search_results_api_download_results(
        self,
        id: UUID,
        format: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> None:
        """Download Results

        Download search results in various formats (tab, fasta, aligned_fasta)

        :param id: (required)
        :type id: str
        :param format: (required)
        :type format: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._pyhmmer_search_results_api_download_results_serialize(
            id=id,
            format=format,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": None,
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def pyhmmer_search_results_api_download_results_with_http_info(
        self,
        id: UUID,
        format: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[None]:
        """Download Results

        Download search results in various formats (tab, fasta, aligned_fasta)

        :param id: (required)
        :type id: str
        :param format: (required)
        :type format: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._pyhmmer_search_results_api_download_results_serialize(
            id=id,
            format=format,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": None,
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def pyhmmer_search_results_api_download_results_without_preload_content(
        self,
        id: UUID,
        format: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Download Results

        Download search results in various formats (tab, fasta, aligned_fasta)

        :param id: (required)
        :type id: str
        :param format: (required)
        :type format: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._pyhmmer_search_results_api_download_results_serialize(
            id=id,
            format=format,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": None,
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _pyhmmer_search_results_api_download_results_serialize(
        self,
        id,
        format,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params["id"] = id
        # process the query parameters
        if format is not None:
            _query_params.append(("format", format))

        # process the header parameters
        # process the form parameters
        # process the body parameter

        # authentication setting
        _auth_settings: List[str] = []

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/api/pyhmmer/result/{id}/download",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def pyhmmer_search_results_api_get_domains_by_target(
        self,
        id: UUID,
        target: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SuccessResponseSchema:
        """Get Domains By Target

        Get domain information for a specific target.

        :param id: (required)
        :type id: str
        :param target: (required)
        :type target: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._pyhmmer_search_results_api_get_domains_by_target_serialize(
            id=id,
            target=target,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "SuccessResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def pyhmmer_search_results_api_get_domains_by_target_with_http_info(
        self,
        id: UUID,
        target: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[SuccessResponseSchema]:
        """Get Domains By Target

        Get domain information for a specific target.

        :param id: (required)
        :type id: str
        :param target: (required)
        :type target: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._pyhmmer_search_results_api_get_domains_by_target_serialize(
            id=id,
            target=target,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "SuccessResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def pyhmmer_search_results_api_get_domains_by_target_without_preload_content(
        self,
        id: UUID,
        target: StrictStr,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Domains By Target

        Get domain information for a specific target.

        :param id: (required)
        :type id: str
        :param target: (required)
        :type target: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._pyhmmer_search_results_api_get_domains_by_target_serialize(
            id=id,
            target=target,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "SuccessResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _pyhmmer_search_results_api_get_domains_by_target_serialize(
        self,
        id,
        target,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params["id"] = id
        # process the query parameters
        if target is not None:
            _query_params.append(("target", target))

        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # authentication setting
        _auth_settings: List[str] = []

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/api/pyhmmer/result/{id}/domains",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    def pyhmmer_search_results_api_get_result(
        self,
        id: UUID,
        page: Optional[StrictInt] = None,
        page_size: Optional[StrictInt] = None,
        taxonomy_ids: Optional[List[Optional[StrictInt]]] = None,
        architecture: Optional[StrictStr] = None,
        with_domains: Optional[StrictBool] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SuccessResponseSchema:
        """Get Result


        :param id: (required)
        :type id: str
        :param page:
        :type page: int
        :param page_size:
        :type page_size: int
        :param taxonomy_ids:
        :type taxonomy_ids: List[Optional[int]]
        :param architecture:
        :type architecture: str
        :param with_domains:
        :type with_domains: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._pyhmmer_search_results_api_get_result_serialize(
            id=id,
            page=page,
            page_size=page_size,
            taxonomy_ids=taxonomy_ids,
            architecture=architecture,
            with_domains=with_domains,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "SuccessResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def pyhmmer_search_results_api_get_result_with_http_info(
        self,
        id: UUID,
        page: Optional[StrictInt] = None,
        page_size: Optional[StrictInt] = None,
        taxonomy_ids: Optional[List[Optional[StrictInt]]] = None,
        architecture: Optional[StrictStr] = None,
        with_domains: Optional[StrictBool] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[SuccessResponseSchema]:
        """Get Result


        :param id: (required)
        :type id: str
        :param page:
        :type page: int
        :param page_size:
        :type page_size: int
        :param taxonomy_ids:
        :type taxonomy_ids: List[Optional[int]]
        :param architecture:
        :type architecture: str
        :param with_domains:
        :type with_domains: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._pyhmmer_search_results_api_get_result_serialize(
            id=id,
            page=page,
            page_size=page_size,
            taxonomy_ids=taxonomy_ids,
            architecture=architecture,
            with_domains=with_domains,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "SuccessResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def pyhmmer_search_results_api_get_result_without_preload_content(
        self,
        id: UUID,
        page: Optional[StrictInt] = None,
        page_size: Optional[StrictInt] = None,
        taxonomy_ids: Optional[List[Optional[StrictInt]]] = None,
        architecture: Optional[StrictStr] = None,
        with_domains: Optional[StrictBool] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Result


        :param id: (required)
        :type id: str
        :param page:
        :type page: int
        :param page_size:
        :type page_size: int
        :param taxonomy_ids:
        :type taxonomy_ids: List[Optional[int]]
        :param architecture:
        :type architecture: str
        :param with_domains:
        :type with_domains: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._pyhmmer_search_results_api_get_result_serialize(
            id=id,
            page=page,
            page_size=page_size,
            taxonomy_ids=taxonomy_ids,
            architecture=architecture,
            with_domains=with_domains,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "SuccessResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _pyhmmer_search_results_api_get_result_serialize(
        self,
        id,
        page,
        page_size,
        taxonomy_ids,
        architecture,
        with_domains,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {
            "taxonomy_ids": "multi",
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if id is not None:
            _path_params["id"] = id
        # process the query parameters
        if page is not None:
            _query_params.append(("page", page))

        if page_size is not None:
            _query_params.append(("page_size", page_size))

        if taxonomy_ids is not None:
            _query_params.append(("taxonomy_ids", taxonomy_ids))

        if architecture is not None:
            _query_params.append(("architecture", architecture))

        if with_domains is not None:
            _query_params.append(("with_domains", with_domains))

        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # authentication setting
        _auth_settings: List[str] = []

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/api/pyhmmer/result/{id}",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )



"""Reactions CLI commands."""

from __future__ import annotations

from typing import List, Optional

import typer  # type: ignore[import]

from ..utils import comma_join, ensure_client, handle_raw_response, merge_params

reactions_app = typer.Typer(help="Reaction endpoints")


@reactions_app.command("search")
def reactions_search(
    ctx: typer.Context,
    locus_tags: Optional[List[str]] = typer.Option(None, "--locus-tag"),
    uniprot_ids: Optional[List[str]] = typer.Option(None, "--uniprot"),
    reaction_id: Optional[str] = typer.Option(None, "--reaction-id"),
    metabolite: Optional[str] = typer.Option(None, "--metabolite"),
    substrate: Optional[str] = typer.Option(None, "--substrate"),
    product: Optional[str] = typer.Option(None, "--product"),
    format: Optional[str] = typer.Option(None, "--format", "-f"),
) -> None:
    client = ensure_client(ctx)
    params = merge_params(
        {
            "locus_tags": comma_join(locus_tags),
            "uniprot_ids": comma_join(uniprot_ids),
            "reaction_id": reaction_id,
            "metabolite": metabolite,
            "substrate": substrate,
            "product": product,
        }
    )
    response = client.raw_request(
        "GET", "/api/reactions/search", params=params, format=format
    )
    handle_raw_response(response, format, title="Reaction search")



"""Request/Responseutilities for the METT Data Portal client."""

from __future__ import annotations

import csv
import io
from typing import Any, Dict, List, Optional

import requests  # type: ignore[import]

from .config import Config
from .exceptions import APIError, AuthenticationError


def parse_tsv_response(tsv_text: str) -> List[Dict[str, Any]]:
    """Parse TSV response into a list of dictionaries.

    Assumes first row contains headers. Returns list of dicts where keys are header names.
    """
    if not tsv_text.strip():
        return []

    reader = csv.DictReader(io.StringIO(tsv_text), delimiter="\t")
    return [dict(row) for row in reader]


def request_json(
    session: requests.Session,
    config: Config,
    endpoint: str,
    *,
    params: Optional[Dict[str, Any]] = None,
) -> Any:
    """Direct HTTP GET for endpoints that don't match the published schema.

    Supports both JSON (default) and TSV (format=tsv) responses.
    """
    url = f"{config.base_url.rstrip('/')}{endpoint}"
    format_type = (params or {}).get("format", "json")

    # Prepare headers based on format
    headers = {}
    if format_type == "tsv":
        headers["Accept"] = "text/tab-separated-values"
    else:
        headers["Accept"] = "application/json"

    try:
        resp = session.get(
            url,
            params=params,
            headers=headers,
            timeout=config.timeout,
            verify=config.verify_ssl,
        )
        resp.raise_for_status()

        # Parse TSV if requested
        if format_type == "tsv":
            return parse_tsv_response(resp.text)

        # Default: parse JSON
        return resp.json()
    except requests.exceptions.HTTPError as exc:
        if exc.response is not None and exc.response.status_code in {401, 403}:
            raise AuthenticationError(
                "Authentication failed", status_code=exc.response.status_code
            ) from exc
        status = exc.response.status_code if exc.response is not None else None
        raise APIError(f"Request failed: {exc}", status_code=status) from exc
    except requests.exceptions.RequestException as exc:
        raise APIError(f"Request failed: {exc}") from exc
    except (ValueError, csv.Error) as exc:
        raise APIError(f"Failed to parse TSV response: {exc}") from exc


__all__ = ["parse_tsv_response", "request_json"]



# coding: utf-8

"""
ME TT DataPortal Data Portal API

ME TT DataPortal Data Portal APIs to fetch Gut Microbes Genomes / Genes information.

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from mett_dataportal_sdk.models.success_response_schema import SuccessResponseSchema

from mett_dataportal_sdk.api_client import ApiClient, RequestSerialized
from mett_dataportal_sdk.api_response import ApiResponse
from mett_dataportal_sdk.rest import RESTResponseType


class EssentialityApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_call
    def dataportal_api_experimental_essentiality_endpoints_search_essentiality(
        self,
        locus_tags: Annotated[
            Optional[StrictStr],
            Field(description="Comma-separated list of locus tags to search for"),
        ] = None,
        uniprot_ids: Annotated[
            Optional[StrictStr],
            Field(description="Comma-separated list of UniProt IDs to search for"),
        ] = None,
        essentiality_call: Annotated[
            Optional[StrictStr],
            Field(
                description="Filter by essentiality call (essential, not_essential, essential_solid, essential_liquid, unclear)"
            ),
        ] = None,
        experimental_condition: Annotated[
            Optional[StrictStr],
            Field(description="Filter by experimental condition/media"),
        ] = None,
        min_tas_in_locus: Annotated[
            Optional[Annotated[int, Field(strict=True, ge=0)]],
            Field(description="Minimum number of transposon insertion sites"),
        ] = None,
        min_tas_hit: Annotated[
            Optional[
                Union[
                    Annotated[float, Field(le=1, strict=True, ge=0)],
                    Annotated[int, Field(le=1, strict=True, ge=0)],
                ]
            ],
            Field(description="Minimum fraction of transposon sites hit (0-1)"),
        ] = None,
        element: Annotated[
            Optional[StrictStr],
            Field(description="Filter by element type (gene, intergenic, etc.)"),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SuccessResponseSchema:
        """Search essentiality data with filters

        Search for essentiality data across genes with optional filters. Supports identifier-based search and discovery mode (filter-only queries).

        :param locus_tags: Comma-separated list of locus tags to search for
        :type locus_tags: str
        :param uniprot_ids: Comma-separated list of UniProt IDs to search for
        :type uniprot_ids: str
        :param essentiality_call: Filter by essentiality call (essential, not_essential, essential_solid, essential_liquid, unclear)
        :type essentiality_call: str
        :param experimental_condition: Filter by experimental condition/media
        :type experimental_condition: str
        :param min_tas_in_locus: Minimum number of transposon insertion sites
        :type min_tas_in_locus: int
        :param min_tas_hit: Minimum fraction of transposon sites hit (0-1)
        :type min_tas_hit: float
        :param element: Filter by element type (gene, intergenic, etc.)
        :type element: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_experimental_essentiality_endpoints_search_essentiality_serialize(
            locus_tags=locus_tags,
            uniprot_ids=uniprot_ids,
            essentiality_call=essentiality_call,
            experimental_condition=experimental_condition,
            min_tas_in_locus=min_tas_in_locus,
            min_tas_hit=min_tas_hit,
            element=element,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "SuccessResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    def dataportal_api_experimental_essentiality_endpoints_search_essentiality_with_http_info(
        self,
        locus_tags: Annotated[
            Optional[StrictStr],
            Field(description="Comma-separated list of locus tags to search for"),
        ] = None,
        uniprot_ids: Annotated[
            Optional[StrictStr],
            Field(description="Comma-separated list of UniProt IDs to search for"),
        ] = None,
        essentiality_call: Annotated[
            Optional[StrictStr],
            Field(
                description="Filter by essentiality call (essential, not_essential, essential_solid, essential_liquid, unclear)"
            ),
        ] = None,
        experimental_condition: Annotated[
            Optional[StrictStr],
            Field(description="Filter by experimental condition/media"),
        ] = None,
        min_tas_in_locus: Annotated[
            Optional[Annotated[int, Field(strict=True, ge=0)]],
            Field(description="Minimum number of transposon insertion sites"),
        ] = None,
        min_tas_hit: Annotated[
            Optional[
                Union[
                    Annotated[float, Field(le=1, strict=True, ge=0)],
                    Annotated[int, Field(le=1, strict=True, ge=0)],
                ]
            ],
            Field(description="Minimum fraction of transposon sites hit (0-1)"),
        ] = None,
        element: Annotated[
            Optional[StrictStr],
            Field(description="Filter by element type (gene, intergenic, etc.)"),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[SuccessResponseSchema]:
        """Search essentiality data with filters

        Search for essentiality data across genes with optional filters. Supports identifier-based search and discovery mode (filter-only queries).

        :param locus_tags: Comma-separated list of locus tags to search for
        :type locus_tags: str
        :param uniprot_ids: Comma-separated list of UniProt IDs to search for
        :type uniprot_ids: str
        :param essentiality_call: Filter by essentiality call (essential, not_essential, essential_solid, essential_liquid, unclear)
        :type essentiality_call: str
        :param experimental_condition: Filter by experimental condition/media
        :type experimental_condition: str
        :param min_tas_in_locus: Minimum number of transposon insertion sites
        :type min_tas_in_locus: int
        :param min_tas_hit: Minimum fraction of transposon sites hit (0-1)
        :type min_tas_hit: float
        :param element: Filter by element type (gene, intergenic, etc.)
        :type element: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_experimental_essentiality_endpoints_search_essentiality_serialize(
            locus_tags=locus_tags,
            uniprot_ids=uniprot_ids,
            essentiality_call=essentiality_call,
            experimental_condition=experimental_condition,
            min_tas_in_locus=min_tas_in_locus,
            min_tas_hit=min_tas_hit,
            element=element,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "SuccessResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    def dataportal_api_experimental_essentiality_endpoints_search_essentiality_without_preload_content(
        self,
        locus_tags: Annotated[
            Optional[StrictStr],
            Field(description="Comma-separated list of locus tags to search for"),
        ] = None,
        uniprot_ids: Annotated[
            Optional[StrictStr],
            Field(description="Comma-separated list of UniProt IDs to search for"),
        ] = None,
        essentiality_call: Annotated[
            Optional[StrictStr],
            Field(
                description="Filter by essentiality call (essential, not_essential, essential_solid, essential_liquid, unclear)"
            ),
        ] = None,
        experimental_condition: Annotated[
            Optional[StrictStr],
            Field(description="Filter by experimental condition/media"),
        ] = None,
        min_tas_in_locus: Annotated[
            Optional[Annotated[int, Field(strict=True, ge=0)]],
            Field(description="Minimum number of transposon insertion sites"),
        ] = None,
        min_tas_hit: Annotated[
            Optional[
                Union[
                    Annotated[float, Field(le=1, strict=True, ge=0)],
                    Annotated[int, Field(le=1, strict=True, ge=0)],
                ]
            ],
            Field(description="Minimum fraction of transposon sites hit (0-1)"),
        ] = None,
        element: Annotated[
            Optional[StrictStr],
            Field(description="Filter by element type (gene, intergenic, etc.)"),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Search essentiality data with filters

        Search for essentiality data across genes with optional filters. Supports identifier-based search and discovery mode (filter-only queries).

        :param locus_tags: Comma-separated list of locus tags to search for
        :type locus_tags: str
        :param uniprot_ids: Comma-separated list of UniProt IDs to search for
        :type uniprot_ids: str
        :param essentiality_call: Filter by essentiality call (essential, not_essential, essential_solid, essential_liquid, unclear)
        :type essentiality_call: str
        :param experimental_condition: Filter by experimental condition/media
        :type experimental_condition: str
        :param min_tas_in_locus: Minimum number of transposon insertion sites
        :type min_tas_in_locus: int
        :param min_tas_hit: Minimum fraction of transposon sites hit (0-1)
        :type min_tas_hit: float
        :param element: Filter by element type (gene, intergenic, etc.)
        :type element: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._dataportal_api_experimental_essentiality_endpoints_search_essentiality_serialize(
            locus_tags=locus_tags,
            uniprot_ids=uniprot_ids,
            essentiality_call=essentiality_call,
            experimental_condition=experimental_condition,
            min_tas_in_locus=min_tas_in_locus,
            min_tas_hit=min_tas_hit,
            element=element,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "SuccessResponseSchema",
        }
        response_data = self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _dataportal_api_experimental_essentiality_endpoints_search_essentiality_serialize(
        self,
        locus_tags,
        uniprot_ids,
        essentiality_call,
        experimental_condition,
        min_tas_in_locus,
        min_tas_hit,
        element,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if locus_tags is not None:
            _query_params.append(("locus_tags", locus_tags))

        if uniprot_ids is not None:
            _query_params.append(("uniprot_ids", uniprot_ids))

        if essentiality_call is not None:
            _query_params.append(("essentiality_call", essentiality_call))

        if experimental_condition is not None:
            _query_params.append(("experimental_condition", experimental_condition))

        if min_tas_in_locus is not None:
            _query_params.append(("min_tas_in_locus", min_tas_in_locus))

        if min_tas_hit is not None:
            _query_params.append(("min_tas_hit", min_tas_hit))

        if element is not None:
            _query_params.append(("element", element))

        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # authentication setting
        _auth_settings: List[str] = ["RoleBasedJWTAuth"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/api/essentiality/search",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )



"""Fitness CLI commands."""

from __future__ import annotations

from typing import List, Optional

import typer  # type: ignore[import]

from ..utils import comma_join, ensure_client, handle_raw_response, merge_params

fitness_app = typer.Typer(help="Fitness endpoints")
fitness_corr_app = typer.Typer(help="Fitness correlation endpoints")


@fitness_app.command("search")
def fitness_search(
    ctx: typer.Context,
    locus_tags: Optional[List[str]] = typer.Option(None, "--locus-tag"),
    uniprot_ids: Optional[List[str]] = typer.Option(None, "--uniprot"),
    contrast: Optional[str] = typer.Option(None, "--contrast"),
    min_lfc: Optional[float] = typer.Option(None, "--min-lfc"),
    max_fdr: Optional[float] = typer.Option(None, "--max-fdr"),
    min_barcodes: Optional[int] = typer.Option(None, "--min-barcodes"),
    format: Optional[str] = typer.Option(None, "--format", "-f"),
) -> None:
    client = ensure_client(ctx)
    params = merge_params(
        {
            "locus_tags": comma_join(locus_tags),
            "uniprot_ids": comma_join(uniprot_ids),
            "contrast": contrast,
            "min_lfc": min_lfc,
            "max_fdr": max_fdr,
            "min_barcodes": min_barcodes,
        }
    )
    response = client.raw_request(
        "GET", "/api/fitness/search", params=params, format=format
    )
    handle_raw_response(response, format, title="Fitness search")


@fitness_corr_app.command("search")
def fitness_correlations_search(
    ctx: typer.Context,
    query: str = typer.Option(..., "--query", "-q"),
    species_acronym: Optional[str] = typer.Option(None, "--species", "-s"),
    page: Optional[int] = typer.Option(None, "--page", "-p"),
    per_page: Optional[int] = typer.Option(None, "--per-page"),
    format: Optional[str] = typer.Option(None, "--format", "-f"),
) -> None:
    client = ensure_client(ctx)
    params = merge_params(
        {
            "query": query,
            "species_acronym": species_acronym,
            "page": page,
            "per_page": per_page,
        }
    )
    response = client.raw_request(
        "GET", "/api/fitness-correlations/search", params=params, format=format
    )
    handle_raw_response(response, format, title="Fitness correlations search")


@fitness_corr_app.command("pair")
def fitness_correlations_pair(
    ctx: typer.Context,
    locus_tag_a: str = typer.Option(..., "--gene-a"),
    locus_tag_b: str = typer.Option(..., "--gene-b"),
    species_acronym: Optional[str] = typer.Option(None, "--species", "-s"),
    format: Optional[str] = typer.Option(None, "--format", "-f"),
) -> None:
    client = ensure_client(ctx)
    params = merge_params(
        {
            "locus_tag_a": locus_tag_a,
            "locus_tag_b": locus_tag_b,
            "species_acronym": species_acronym,
        }
    )
    response = client.raw_request(
        "GET", "/api/fitness-correlations/correlation", params=params, format=format
    )
    handle_raw_response(response, format, title="Gene fitness correlation")



"""Typer-based CLI wired into the high-level DataPortalClient."""

from __future__ import annotations

from typing import Optional

import typer  # type: ignore[import]

from .core import genes_app, genomes_app, species_app, system_app
from .experimental import (
    drugs_app,
    essentiality_app,
    fitness_app,
    fitness_corr_app,
    mutant_app,
    operons_app,
    orthologs_app,
    proteomics_app,
    reactions_app,
)
from .interactions import ppi_app, ttp_app
from .other import api_app, pyhmmer_app
from .utils import _build_client
from ..version import __version__

app = typer.Typer(help="METT Data Portal CLI")

# Register all sub-apps
app.add_typer(system_app, name="system")
app.add_typer(species_app, name="species")
app.add_typer(genomes_app, name="genomes")
app.add_typer(genes_app, name="genes")
app.add_typer(drugs_app, name="drugs")
app.add_typer(proteomics_app, name="proteomics")
app.add_typer(essentiality_app, name="essentiality")
app.add_typer(fitness_app, name="fitness")
app.add_typer(fitness_corr_app, name="fitness-correlations")
app.add_typer(mutant_app, name="mutant-growth")
app.add_typer(reactions_app, name="reactions")
app.add_typer(operons_app, name="operons")
app.add_typer(orthologs_app, name="orthologs")
app.add_typer(ttp_app, name="ttp")
app.add_typer(ppi_app, name="ppi")
app.add_typer(pyhmmer_app, name="pyhmmer")
app.add_typer(api_app, name="api")


@app.callback(invoke_without_command=True)
def main(
    ctx: typer.Context,
    base_url: Optional[str] = typer.Option(None, help="Override the API base URL"),
    jwt: Optional[str] = typer.Option(
        None, help="JWT token for experimental endpoints"
    ),
    timeout: Optional[int] = typer.Option(None, help="HTTP timeout (seconds)"),
    verify_ssl: Optional[bool] = typer.Option(
        None, help="Set false to skip TLS verification"
    ),
    version: bool = typer.Option(
        False, "--version", "-v", help="Show version and exit"
    ),
) -> None:
    """Initialize shared client and stash in Typer context."""

    if version:
        typer.echo(f"mett {__version__}")
        raise typer.Exit()

    ctx.obj = _build_client(
        base_url=base_url,
        jwt=jwt,
        timeout=timeout,
        verify_ssl=verify_ssl,
    )


if __name__ == "__main__":
    app()



# coding: utf-8

"""
ME TT DataPortal Data Portal API

ME TT DataPortal Data Portal APIs to fetch Gut Microbes Genomes / Genes information.

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from mett_dataportal_sdk.models.pagination_metadata_schema import (
    PaginationMetadataSchema,
)
from mett_dataportal_sdk.models.ppi_interaction_schema import PPIInteractionSchema
from mett_dataportal_sdk.models.response_status import ResponseStatus
from typing import Set
from typing_extensions import Self


class PPISearchResponseSchema(BaseModel):
    """
    Response schema for PPI search results.
    """  # noqa: E501

    status: Optional[ResponseStatus] = Field(
        default=None, description="Response status"
    )
    message: Optional[StrictStr] = None
    timestamp: StrictStr = Field(description="ISO 8601 timestamp of the response")
    data: List[PPIInteractionSchema]
    pagination: PaginationMetadataSchema = Field(description="Pagination metadata")
    __properties: ClassVar[List[str]] = [
        "status",
        "message",
        "timestamp",
        "data",
        "pagination",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PPISearchResponseSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in data (list)
        _items = []
        if self.data:
            for _item_data in self.data:
                if _item_data:
                    _items.append(_item_data.to_dict())
            _dict["data"] = _items
        # override the default output from pydantic by calling `to_dict()` of pagination
        if self.pagination:
            _dict["pagination"] = self.pagination.to_dict()
        # set to None if message (nullable) is None
        # and model_fields_set contains the field
        if self.message is None and "message" in self.model_fields_set:
            _dict["message"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PPISearchResponseSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "status": obj.get("status"),
                "message": obj.get("message"),
                "timestamp": obj.get("timestamp"),
                "data": [PPIInteractionSchema.from_dict(_item) for _item in obj["data"]]
                if obj.get("data") is not None
                else None,
                "pagination": PaginationMetadataSchema.from_dict(obj["pagination"])
                if obj.get("pagination") is not None
                else None,
            }
        )
        return _obj



"""Essentiality CLI commands."""

from __future__ import annotations

from typing import List, Optional

import typer  # type: ignore[import]

from ..utils import comma_join, ensure_client, handle_raw_response, merge_params

essentiality_app = typer.Typer(help="Essentiality endpoints")


@essentiality_app.command("search")
def essentiality_search(
    ctx: typer.Context,
    locus_tags: Optional[List[str]] = typer.Option(None, "--locus-tag"),
    uniprot_ids: Optional[List[str]] = typer.Option(None, "--uniprot"),
    essentiality_call: Optional[str] = typer.Option(None, "--call"),
    experimental_condition: Optional[str] = typer.Option(None, "--condition"),
    min_tas_in_locus: Optional[int] = typer.Option(None, "--min-tas-in-locus"),
    min_tas_hit: Optional[float] = typer.Option(None, "--min-tas-hit"),
    element: Optional[str] = typer.Option(None, "--element"),
    format: Optional[str] = typer.Option(None, "--format", "-f"),
) -> None:
    client = ensure_client(ctx)
    params = merge_params(
        {
            "locus_tags": comma_join(locus_tags),
            "uniprot_ids": comma_join(uniprot_ids),
            "essentiality_call": essentiality_call,
            "experimental_condition": experimental_condition,
            "min_tas_in_locus": min_tas_in_locus,
            "min_tas_hit": min_tas_hit,
            "element": element,
        }
    )
    response = client.raw_request(
        "GET", "/api/essentiality/search", params=params, format=format
    )
    handle_raw_response(response, format, title="Essentiality search")



"""System and metadata CLI commands."""

from __future__ import annotations

from typing import Optional

import typer  # type: ignore[import]

from ..utils import ensure_client, handle_raw_response

system_app = typer.Typer(help="System / metadata endpoints")


@system_app.command("health")
def system_health(
    ctx: typer.Context,
    format: Optional[str] = typer.Option(None, "--format", "-f", help="json|tsv"),
) -> None:
    client = ensure_client(ctx)
    response = client.raw_request("GET", "/api/health", format=format)
    handle_raw_response(response, format, title="Health Check")


@system_app.command("features")
def system_features(
    ctx: typer.Context,
    format: Optional[str] = typer.Option(None, "--format", "-f", help="json|tsv"),
) -> None:
    client = ensure_client(ctx)
    response = client.raw_request("GET", "/api/features", format=format)
    handle_raw_response(response, format, title="Feature Flags")


@system_app.command("cog-categories")
def system_cog_categories(
    ctx: typer.Context,
    format: Optional[str] = typer.Option(None, "--format", "-f"),
) -> None:
    client = ensure_client(ctx)
    response = client.raw_request("GET", "/api/metadata/cog-categories", format=format)
    handle_raw_response(response, format, title="COG Categories")
